@@ -18,6 +18,7 @@
 #include <utils/elidinglabel.h>
 #include <utils/link.h>
 #include <utils/multitextcursor.h>
+#include <utils/plaintextedit/plaintextedit.h>
 #include <utils/textutils.h>
 #include <utils/uncommentselection.h>
 
@@ -127,7 +128,9 @@ public:
     virtual void finalizeInitialization() {}
 
     static BaseTextEditor *currentTextEditor();
-    static QVector<BaseTextEditor *> textEditorsForDocument(TextDocument *textDocument);
+    static QList<BaseTextEditor *> openedTextEditors();
+    static QList<BaseTextEditor *> textEditorsForDocument(TextDocument *textDocument);
+    static QList<BaseTextEditor *> textEditorsForFilePath(const Utils::FilePath &path);
 
     TextEditorWidget *editorWidget() const;
     TextDocument *textDocument() const;
@@ -189,7 +192,7 @@ private:
     Internal::BaseTextEditorPrivate *d;
 };
 
-class TEXTEDITOR_EXPORT TextEditorWidget : public QPlainTextEdit
+class TEXTEDITOR_EXPORT TextEditorWidget : public Utils::PlainTextEdit
 {
     Q_OBJECT
 public:
@@ -211,7 +214,7 @@ public:
     QTextCursor textCursorAt(int position) const;
     Utils::Text::Position lineColumn() const;
     void convertPosition(int pos, int *line, int *column) const;
-    using QPlainTextEdit::cursorRect;
+    using PlainTextEdit::cursorRect;
     QRect cursorRect(int pos) const;
     void setCursorPosition(int pos);
     QWidget *toolBarWidget() const;
@@ -351,6 +354,7 @@ public:
 
     enum Side { Left, Right };
     QAction *insertExtraToolBarWidget(Side side, QWidget *widget);
+    void insertExtraToolBarAction(Side side, QAction *action);
     void setToolbarOutline(QWidget* widget);
     const QWidget *toolbarOutlineWidget();
 
@@ -499,7 +503,7 @@ public:
     void configureGenericHighlighter(const Utils::MimeType &mimeType);
 
     /// Overwrite the current highlighter with a new generic highlighter based on the given definition
-    Utils::expected_str<void> configureGenericHighlighter(const QString &definitionName);
+    Utils::Result<> configureGenericHighlighter(const QString &definitionName);
 
     Q_INVOKABLE void inSnippetMode(bool *active); // Used by FakeVim.
 
@@ -581,7 +585,7 @@ protected:
     virtual void paintBlock(QPainter *painter,
                             const QTextBlock &block,
                             const QPointF &offset,
-                            const QVector<QTextLayout::FormatRange> &selections,
+                            const QList<QTextLayout::FormatRange> &selections,
                             const QRect &clipRect) const;
     void timerEvent(QTimerEvent *) override;
     void mouseMoveEvent(QMouseEvent *) override;
